#
# spec file for package gom
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gom
Version:        0.5.3
Release:        1.4
Summary:        GObject Data Mapper
License:        LGPL-2.1-or-later
Group:          Development/Libraries/GNOME
URL:            https://git.gnome.org/browse/gom/
Source:         https://download.gnome.org/sources/gom/0.5/%{name}-%{version}.tar.xz
BuildRequires:  meson >= 0.38.1
BuildRequires:  pkgconfig
BuildRequires:  python3-gobject
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gio-2.0) >= 2.36
BuildRequires:  pkgconfig(gobject-2.0) >= 2.36
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(sqlite3) >= 3.7

%description
This is a DataMapper for GObject.

%package -n libgom-1_0-0
Summary:        GObject Data Mapper
Group:          System/Libraries
Obsoletes:      gom-lang

%description -n libgom-1_0-0
This is a DataMapper for GObject.

%package -n typelib-1_0-Gom-1_0
Summary:        Introspection bindings for the GObject Data Mapper
Group:          System/Libraries

%description -n typelib-1_0-Gom-1_0
This is a DataMapper for GObject.

This package provides the GObject Introspection bindings for gom.

%package -n python3-gom
Summary:        Python3 binding for the GObject Dara Mapper
Group:          Development/Languages/Python
Supplements:    packageand(python3:typelib-1_0-Gom-1_0)

%description -n python3-gom
This is a DataMapper for GObject.

With this package you can glue gom to python3.

%package devel
Summary:        Development files for the GObject Data Mapper
Group:          Development/Libraries/GNOME
Requires:       libgom-1_0-0 = %{version}
Requires:       python3-gom = %{version}
Requires:       typelib-1_0-Gom-1_0 = %{version}

%description  devel
This is a DataMapper for GObject.

%prep
%setup -q

%build
%meson
%meson_build

%check
# Temp disable tests while we figure out why it times out on x86_64
#meson_test

%install
%meson_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libgom-1_0-0 -p /sbin/ldconfig
%postun -n libgom-1_0-0 -p /sbin/ldconfig

%files -n libgom-1_0-0
%license COPYING
%doc README
%{_libdir}/libgom-1.0.so.*

%files -n typelib-1_0-Gom-1_0
%{_libdir}/girepository-1.0/Gom-1.0.typelib

%files -n python3-gom
%{python3_sitearch}/gi/overrides/Gom.py

%files devel
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/gom-1.0/
%{_datadir}/gir-1.0/*.gir

%changelog
* Sun Aug 11 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.5.3:
  + Automatically ignore read-only properties
  + Add support for GParamSpec which are GBytes
* Tue Jul  9 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.5.2:
  + Fix a mismatched g_mutex_init()/g_mutex_clear() which caused an
    issue with MUSL-based systems.
* Thu Apr 11 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.5.1:
  + Reduce object inflation overhead in GType system usage.
  + Avoid some allocations in hot paths.
  + Avoid hashtables for resourcegroup items.
  + Avoid use of weak pointers when unnecessary.
* Mon Mar  4 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.5.0:
  + Add missing cleanup attribute for GomSorting.
  + Fix sorting example.
  + Add g_critical() on invalid API use.
  + Async fixes to support concurrent fetch and get_idnex().
  + Fix leak of table name.
  + Generate documentation using gi-docgen.
  + Fix improper usage of GHfunc.
  + Various code structure cleanups.
* Mon Feb 17 2020 bjorn.lie@gmail.com
- Update to version 0.4:
  + Fix primary-keys never being monitored, which triggered crashes
    with GLib 2.63.
  + Test for invalid table names.
  + Install Python overrides in correct location.
  + Fix storage of NULL GDateTime values.
  + Fix constraints test under older versions of SQLite.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Wed Sep 13 2017 dimstar@opensuse.org
- Split out python3-gom: the python/gi binding were wrongly
  packaged as part of the -devel package.
- Run spec-cleaner: adds pkgconfig-BuildRequires.
* Fri Sep  8 2017 jengelh@inai.de
- Update summaries an RPM groups. Trim non-telling parts of
  descriptions.
* Thu Jul 20 2017 zaitor@opensuse.org
- Temp disable meson_check while we figure out why it randomly
  fails on x86_64.
* Thu Jun 22 2017 zaitor@opensuse.org
- Update to version 0.3.3:
  + Replace hardcoded values in pkg-config file.
  + Add a JavaScript example.
  + Remove i18n support, as there are no user-visible strings.
  + Replace autotools build system with meson.
- Add meson BuildRequires and switch autotools macros configure,
  make, make test and makeinstall to meson, meson_build, meson_test
  and meson_install following upstream switch to Meson build
  system.
- Add explicit python3-gobject BuildRequires to workaround
  build-fail, upstream expects everyone to have moved to python3 as
  default python.
- Drop intltool BuildRequires: No longer needed.
- Following the above, drop lang subpackage and macros handling
  translations, and drop gom-lang Recommends and gom Provides from
  libgom-1_0-0 subpackage. Add gom-lang Obsoletes to ease updates.
* Sun Dec 27 2015 damjanovic.ivo@gmail.com
- Updated to version 0.3.2:
  + Add missing annotation for repository object.
  + Support ordering queries.
  + Add support for creating new tables in a version.
  + Fix memory leak in GomResource.
  + Bindings:
  - Add missing annotation for repository object.
  - Add a working Python example.
  - Make ResourceGroup a sequence in Python bindings.
* Wed Apr 29 2015 zaitor@opensuse.org
- Update to version 0.3.1:
  + Support g_autoptr() for all gom object types.
  + Add IS NULL and IS NOT NULL filters.
  + Add gom_resource_group_delete_[a]sync functions.
  + Fix crash on 64-bit systems with some compiler/compiler flags.
  + Fix saving a modified resource a second time.
  + Fix setting ID after calling gom_resource_group_write_*.
- Add a %%check section and pass %%{__make} test to it. Actually run
  the already enabled tests. This adds quite a bit to build time,
  but all testing we can get is good.
* Tue Feb 17 2015 dimstar@opensuse.org
- Update to version 0.3.0:
  + Update COPYING to LGPL 2.1+ to match headers.
  + Add support for batched writes.
  + Support the GLOB operator.
  + Fix stacking of filters.
  + Fix possible crashes on exit.
  + Remove "adapter" property from GomResourceGroup.
  + Fix a bug in automatic migration.
  + Fix a number of bugs related to using GOM in bindings and in
    multi-thread unsafe interpreters.
  + Make gdk-pixbuf an optional dependency.
* Mon Aug 25 2014 zaitor@opensuse.org
- Initial packaging version 0.2.1
